@@ -1,4 +1,4 @@
-from mindsdb_evaluator.accuracy.general import evaluate_accuracy
+from mindsdb_evaluator.accuracy.general import evaluate_accuracy, evaluate_accuracies
 from mindsdb_evaluator.accuracy.regression import evaluate_regression_accuracy
 from mindsdb_evaluator.accuracy.classification import evaluate_multilabel_accuracy
 from mindsdb_evaluator.accuracy.forecasting import \
@@ -7,6 +7,6 @@ from mindsdb_evaluator.accuracy.forecasting import \
     evaluate_cat_array_accuracy, \
     complementary_smape_array_accuracy
 
-__all__ = ['evaluate_accuracy', 'evaluate_regression_accuracy', 'evaluate_multilabel_accuracy',
+__all__ = ['evaluate_accuracy', 'evaluate_accuracies', 'evaluate_regression_accuracy', 'evaluate_multilabel_accuracy',
            'evaluate_array_accuracy', 'evaluate_num_array_accuracy', 'evaluate_cat_array_accuracy',
            'complementary_smape_array_accuracy']  # noqa
\ No newline at end of file
